Simple tests
------------

Ensure your device works with these simple tests.

.. literalinclude:: ../examples/focaltouch_print_touches.py
    :caption: examples/focaltouch_print_touches.py
    :linenos:

.. literalinclude:: ../examples/focaltouch_paint_simpletest.py
    :caption: examples/focaltouch_paint_simpletest.py
    :linenos:
